# exchange-client

This package is a wrapper around exchangelib, facilitating easy creation,
update and deletion of calendar events.

## Why not just use exchangelib?

Three good reasons:
- Separation of concerns
- Make sure we actually use the appropriate identifier for calendar items
- One does not simply create an item in Exchange

## Identifiers in Exchange

Each calender item created has a field `id`, which uniquely identifies the
calendar item in Exchange. This field can change, depending on a multitude of
factors.

exchange-client registers an extended property on calendar items, that allows
us to attach a custom string to each calendar item. This custom string can in
turn be used to locate calendar items reliably at a later time.

The extended property identifier is set by the `identity_property_name`
argument supplied to `ExchangeClient` when initializing. The identifier will
allow multiple integrations to use `exchange-client` simultaneously.

The observant user will notice that operations like `update_item()` and
`delete_item()` returns a list of calendar items. The list contains all
calendar items that has been acted upon when the operation was performed, as
there is a possibility for users to copy calendar items (the extended property
is a part of the calendar item).

## Usage

Initialize exchange-client

    import exchange_client
    c = exchange_client.ExchangeClient(
        'my-persistent-identifier-for-identifiers',
        'mail.example.com',
        'example.com\my_service_account',
        'my_password')

Get an account

    account = c.account('primary_address@example.com')

Create a calendar item

    item = c.create_item(
        account,
        'a-string-that-uniquely-identifies-this-item',
        'The subject',
        'The body',
        datetime.datetime.now(),
        datetime.datetime.now() + datetime.timedelta(hours=3))

Update the created calendar item

    for x in c.update_item(
            account,
            'a-string-that-uniquely-identifies-this-item',
            'A long meeting',
            'A longer agenda…',
            datetime.datetime.now() + datetime.timedelta(seconds=50),
            datetime.datetime.now() + datetime.timedelta(hours=10):
        print(x)

Delete an item

    for x in c.delete_item(account, 'a-string-that-uniquely-identifies-this-item'):
        print(x)
